==> kdevplatform_1.6.0.orig.tar.xz: kdevplatform-1.6.0/plugins/executescript/kdevexecutescript.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=This plugin allows running of scripts.
Comment[bs]=Ovaj dodatak dopušta pogretanje skripti
Comment[ca]=Aquest connector permet executar scripts.
Comment[ca@valencia]=Este connector permet executar scripts.
Comment[da]=Dette plugin lader dig køre scripts.
Comment[de]=Dieses Modul ermöglicht das Ausführen von Skripten.
Comment[el]=Το πρόσθετο αυτό επιτρέπει την εκτέλεση σεναρίων.
Comment[es]=Este complemento permite ejecutar scripts.
Comment[et]=See plugin võimaldab käivitada skripte.
Comment[fi]=Tämä liitännäinen mahdollistaa skriptien suorittamisen.
Comment[fr]=Ce module externe permet d'exécuter des scripts.
Comment[gl]=Este complemento permite a execución de scripts.
Comment[hu]=Ez a bővítmény lehetővé teszi parancsfájlok futtatását.
Comment[it]=Questa estensione permette l'esecuzione degli script.
Comment[kk]=Бұл плагині скриптті орындауға мүмкіндік береді.
Comment[nb]=Dette programtillegget tillater skriptkjøring.
Comment[nds]=Dit Moduul maakt dat Opropen vun Skripten mööglich.
Comment[nl]=Deze plugin staat het uitvoeren van scripts toe.
Comment[pl]=Wtyczka ta pozwala na uruchamianie skryptów.
Comment[pt]=Este 'plugin' permite a execução de programas.
Comment[pt_BR]=Este plugin permite a execução de programas.
Comment[ru]=Это расширение позволяет запускать сценарии.
Comment[sk]=Tento plugin povoľuje spúšťanie skriptov.
Comment[sl]=Ta vstavek omogoča zaganjanje skript.
Comment[sv]=Insticksprogrammet gör det möjligt att köra skript.
Comment[tr]=Bu eklenti betiklerin çalıştırılmasını sağlar.
Comment[uk]=За допомогою цього додатка можна запускати скрипти.
Comment[x-test]=xxThis plugin allows running of scripts.xx
Comment[zh_CN]=此插件负责执行脚本。
Comment[zh_TW]=此外掛程式允許執行文稿。
Name=Execute Scripts
Name[bs]=Izvrši skruptu
Name[ca]=Executa scripts
Name[ca@valencia]=Executa scripts
Name[cs]=Spustit skripty
Name[da]=Kør scripts
Name[de]=Skripte ausführen
Name[el]=Εκτέλεση σεναρίων
Name[es]=Ejecutar scripts
Name[et]=Skriptide käivitamine
Name[fi]=Skriptien suorittaminen
Name[fr]=Exécution de scripts
Name[ga]=Rith Scripteanna
Name[gl]=Executar scripts
Name[hu]=Parancsfájlok végrehajtása
Name[it]=Esegui script
Name[kk]=Скрипттерді орындқу
Name[nb]=Kjør skripter
Name[nds]=Skripten utföhren
Name[nl]=Scripts uitvoeren
Name[pl]=Wykonaj skrypty
Name[pt]=Executar Programas
Name[pt_BR]=Executar os programas
Name[ru]=Запуск сценариев
Name[sk]=Spustiť skripty
Name[sl]=Izvedi skripte
Name[sv]=Kör skript
Name[tr]=Betikleri Çalıştır
Name[uk]=Виконання скриптів
Name[x-test]=xxExecute Scriptsxx
Name[zh_CN]=执行脚本
Name[zh_TW]=執行文稿
GenericName=Script Execution Support
GenericName[bs]=Podrška za izvršenje skripte
GenericName[ca]=Implementació d'execució d'scripts
GenericName[ca@valencia]=Implementació d'execució d'scripts
GenericName[da]=Understøttelse af script-kørsel
GenericName[de]=Unterstützung zur Ausführung von Skripten
GenericName[el]=Υποστήριξη εκτέλεσης σεναρίων
GenericName[es]=Implementación de la ejecución de scripts
GenericName[et]=Skriptide käivitamise toetus
GenericName[fi]=Skriptiensuoritustuki
GenericName[fr]=Prise en charge de l'exécution de scripts
GenericName[gl]=Soporte de execución de scripts
GenericName[hu]=Parancsfájl-végrehajtás támogatás
GenericName[it]=Supporto esecuzione script
GenericName[kk]=Скриптті орындауын қолдау
GenericName[nb]=Støtte for skriptkjøring
GenericName[nds]=Ünnerstütten för't Utföhren vun Skripten
GenericName[nl]=Ondersteuning voor uitvoeren van scripts
GenericName[pl]=Obsługa wykonywania skryptów
GenericName[pt]=Suporte à Execução de Programas
GenericName[pt_BR]=Suporte à execução de programas
GenericName[ru]=Поддержка запуска сценариев
GenericName[sk]=Podpora spúšťania skriptov
GenericName[sl]=Podpora izvajanju skript
GenericName[sv]=Stöd för körning av skript
GenericName[tr]=Betik Çalıştırma Desteği
GenericName[uk]=Підтримка виконання скриптів
GenericName[x-test]=xxScript Execution Supportxx
GenericName[zh_CN]=脚本执行支持
GenericName[zh_TW]=執行文稿支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevexecutescript
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevexecutescript
X-KDE-PluginInfo-Author=Niko Sams
X-KDE-PluginInfo-License=GPL
X-KDevelop-Interfaces=org.kdevelop.IExecuteScriptPlugin
X-KDevelop-Mode=NoGUI

==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/executescript/kdevexecutescript.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=This plugin allows running of scripts.
Comment[bg]=Тази приставка позволява изпълнение на скриптове.
Comment[bs]=Ovaj dodatak dopušta pogretanje skripti
Comment[ca]=Aquest connector permet executar scripts.
Comment[ca@valencia]=Este connector permet executar scripts.
Comment[da]=Dette plugin lader dig køre scripts.
Comment[de]=Dieses Modul ermöglicht das Ausführen von Skripten.
Comment[el]=Το πρόσθετο αυτό επιτρέπει την εκτέλεση σεναρίων.
Comment[es]=Este complemento permite ejecutar scripts.
Comment[et]=See plugin võimaldab käivitada skripte.
Comment[fi]=Tämä liitännäinen mahdollistaa skriptien suorittamisen.
Comment[fr]=Ce module externe permet d'exécuter des scripts.
Comment[gl]=Este complemento permite a execución de scripts.
Comment[hu]=Ez a bővítmény lehetővé teszi parancsfájlok futtatását.
Comment[it]=Questa estensione permette l'esecuzione degli script.
Comment[kk]=Бұл плагині скриптті орындауға мүмкіндік береді.
Comment[nb]=Dette programtillegget tillater skriptkjøring.
Comment[nds]=Dit Moduul maakt dat Opropen vun Skripten mööglich.
Comment[nl]=Deze plugin staat het uitvoeren van scripts toe.
Comment[pl]=Wtyczka ta pozwala na uruchamianie skryptów.
Comment[pt]=Este 'plugin' permite a execução de programas.
Comment[pt_BR]=Este plugin permite a execução de programas.
Comment[ru]=Это расширение позволяет запускать сценарии.
Comment[sk]=Tento plugin povoľuje spúšťanie skriptov.
Comment[sl]=Ta vstavek omogoča zaganjanje skript.
Comment[sv]=Insticksprogrammet gör det möjligt att köra skript.
Comment[tr]=Bu eklenti betiklerin çalıştırılmasını sağlar.
Comment[uk]=За допомогою цього додатка можна запускати скрипти.
Comment[x-test]=xxThis plugin allows running of scripts.xx
Comment[zh_CN]=此插件负责执行脚本.
Comment[zh_TW]=此外掛程式允許執行文稿。
Name=Execute Scripts
Name[bg]=Изпълнение на скриптове
Name[bs]=Izvrši skruptu
Name[ca]=Executa scripts
Name[ca@valencia]=Executa scripts
Name[cs]=Spustit skripty
Name[da]=Kør scripts
Name[de]=Skripte ausführen
Name[el]=Εκτέλεση σεναρίων
Name[es]=Ejecutar scripts
Name[et]=Skriptide käivitamine
Name[fi]=Skriptien suorittaminen
Name[fr]=Exécution de scripts
Name[ga]=Rith Scripteanna
Name[gl]=Executar scripts
Name[hu]=Parancsfájlok végrehajtása
Name[it]=Esegui script
Name[kk]=Скрипттерді орындқу
Name[nb]=Kjør skripter
Name[nds]=Skripten utföhren
Name[nl]=Scripts uitvoeren
Name[pl]=Wykonaj skrypty
Name[pt]=Executar Programas
Name[pt_BR]=Executar os programas
Name[ru]=Запуск сценариев
Name[sk]=Spustiť skripty
Name[sl]=Izvedi skripte
Name[sv]=Kör skript
Name[tr]=Betikleri Çalıştır
Name[uk]=Виконання скриптів
Name[x-test]=xxExecute Scriptsxx
Name[zh_CN]=执行脚本
Name[zh_TW]=執行文稿
GenericName=Script Execution Support
GenericName[bg]=Поддръжка за изпълнение на скриптове
GenericName[bs]=Podrška za izvršenje skripte
GenericName[ca]=Implementació d'execució d'scripts
GenericName[ca@valencia]=Implementació d'execució d'scripts
GenericName[da]=Understøttelse af script-kørsel
GenericName[de]=Unterstützung zur Ausführung von Skripten
GenericName[el]=Υποστήριξη εκτέλεσης σεναρίων
GenericName[es]=Implementación de la ejecución de scripts
GenericName[et]=Skriptide käivitamise toetus
GenericName[fi]=Skriptiensuoritustuki
GenericName[fr]=Prise en charge de l'exécution de scripts
GenericName[gl]=Soporte de execución de scripts
GenericName[hu]=Parancsfájl-végrehajtás támogatás
GenericName[it]=Supporto esecuzione script
GenericName[kk]=Скриптті орындауын қолдау
GenericName[nb]=Støtte for skriptkjøring
GenericName[nds]=Ünnerstütten för't Utföhren vun Skripten
GenericName[nl]=Ondersteuning voor uitvoeren van scripts
GenericName[pl]=Obsługa wykonywania skryptów
GenericName[pt]=Suporte à Execução de Programas
GenericName[pt_BR]=Suporte à execução de programas
GenericName[ru]=Поддержка запуска сценариев
GenericName[sk]=Podpora spúšťania skriptov
GenericName[sl]=Podpora izvajanju skript
GenericName[sv]=Stöd för körning av skript
GenericName[tr]=Betik Çalıştırma Desteği
GenericName[uk]=Підтримка виконання скриптів
GenericName[x-test]=xxScript Execution Supportxx
GenericName[zh_CN]=脚本执行支持
GenericName[zh_TW]=執行文稿支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevexecutescript
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevexecutescript
X-KDE-PluginInfo-Author=Niko Sams
X-KDE-PluginInfo-License=GPL
X-KDevelop-Interfaces=org.kdevelop.IExecuteScriptPlugin
X-KDevelop-Mode=NoGUI
